
# Slot: test_attribute




URI: [ks:fakeClass__test_attribute](https://w3id.org/linkml/tests/kitchen_sink/fakeClass__test_attribute)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [FakeClass](FakeClass.md)
